/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.osi;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonValue;

import lombok.AccessLevel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.RequiredArgsConstructor;
import lombok.Singular;
import lombok.ToString;

@Getter
@NoArgsConstructor(access = AccessLevel.PRIVATE)
@AllArgsConstructor
@ToString
@Builder
public class Message {

	@RequiredArgsConstructor
	public enum EidasLevel {
		LOW(0), MEDIUM(1), HIGH(2);

		private final int numValue;

		@JsonValue
		public int toValue() {
			return numValue;
		}
	}

	private String messageId;

	@JsonProperty("sequenceNumber")
	private String vorgangId;

	@JsonProperty("nameIdentifier")
	private String postfachId;

	private String subject;
	@JsonProperty("body")
	private String mailBody;

	@JsonProperty("isHtml")
	private boolean isHtml;

	@JsonProperty("replyAction")
	@Builder.Default
	private ReplyOption replyOption = ReplyOption.FORBIDDEN;
	@Builder.Default
	private EidasLevel eidasLevel = EidasLevel.MEDIUM;

	@JsonProperty("isObligatory")
	private boolean rechtsverbindlich;

	@Singular
	private List<MessageAttachment> attachments;
}
