package de.ozgcloud.nachrichten.postfach.bayernid;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.EnumSource;
import org.mockito.InjectMocks;

class BayernIdPostfachResponseHandlerTest {

	@InjectMocks
	private BayernIdPostfachResponseHandler handler;

	@Nested
	@DisplayName("Test successful Postfachserver response")
	class TestSuccessfulPostfachServerResponse {

		@Test
		void shouldNotThrowAnyException() {
			assertThatCode(() -> handler.handleResponse(BayernIdResponseTestFactory.create())).doesNotThrowAnyException();
		}
	}

	@Nested
	@DisplayName("Test faulty Postfachserver response ")
	class TestFaultyPostfachserverResponse {

		@DisplayName("Fehler im OK.KOMM-Schema")
		@ParameterizedTest(name = "when response status: {0}")
		@EnumSource(value = MailSendingResponseStatus.class, mode = EnumSource.Mode.EXCLUDE, names = { "SUCCESS" })
		void shouldThrowPostfachBadRequestExceptionForSchluessel(MailSendingResponseStatus responseStatus) {
			var bayernIdResponse = BayernIdResponseTestFactory.createBuilder().success(false).status(responseStatus.getSchluessel()).build();

			var exception = Assertions.assertThrows(BayernIdServerException.class, () -> handler.handleResponse(bayernIdResponse));
			assertThat(exception.getMessage()).startsWith("9006 / %s / %s".formatted(responseStatus.getSchluessel(), responseStatus.getMessage()));
		}

	}
}