package de.ozgcloud.nachrichten.postfach.osi;

import java.util.List;
import java.util.stream.Collectors;

import de.ozgcloud.common.test.TestUtils;
import lombok.Builder;
import lombok.Singular;

public class MessageJsonReplyTestFactory {

	public static final MessageAttachment MESSAGE_ATTACHMENT = MessageAttachmentTestFactory.create();

	public static String create() {
		return createBuilder().build();
	}

	public static MessageJsonReply.MessageJsonReplyBuilder createBuilder() {
		return MessageJsonReply.builder()
				.messageId(MessageTestFactory.MESSAGE_ID)
				.postfachId(MessageTestFactory.POSTFACH_ID)
				.mailBody(MessageTestFactory.MAIL_BODY)
				.replyOption(MessageTestFactory.REPLY_OPTION)
				.subject(MessageTestFactory.SUBJECT)
				.vorgangId(MessageTestFactory.VORGANG_ID)
				.attachment(MESSAGE_ATTACHMENT);
	}

	@Builder
	private static class MessageJsonReply {

		private static final String REPLY_MESSAGE_JSON_TMPL = "reply-message-json.tmpl";

		private static final String ATTACHMENT_TMPL = """
				{
				  "fileName": "%s",
				  "content": "%s"
				}""";

		private String messageId;
		private String postfachId;
		private String mailBody;
		private ReplyOption replyOption;
		private String subject;
		private String vorgangId;
		@Singular
		private List<MessageAttachment> attachments;

		public static class MessageJsonReplyBuilder {

			public String build() {
				return TestUtils.loadTextFile(REPLY_MESSAGE_JSON_TMPL)
						.formatted(messageId, postfachId, mailBody, replyOption.toValue(), subject, vorgangId,
								buildAttachments());
			}

			public String buildAttachments() {
				return attachments.stream().map(attachment -> ATTACHMENT_TMPL.formatted(attachment.getFileName(), attachment.getContent()))
						.collect(Collectors.joining(","));
			}
		}
	}

}
